"use client"

import { createCommissionExtra } from "@/actions/items/commissions/types/newType"
import { Button } from "@/components/ui/button"
import { DualRangeSlider } from "@/components/ui/dual-range"
import {
  FormControl,
  FormField,
  FormItem,
  FormLabel,
} from "@/components/ui/form"
import { Input } from "@/components/ui/input"
import { CommissionExtra } from "@/generated/prisma"
import { useState } from "react"
import { useFieldArray, useFormContext } from "react-hook-form"
import { ComboboxCreateable } from "./ComboboxCreateable"

type Props = {
  extras: CommissionExtra[]
}

export function CommissionExtraField({ extras: initialExtras }: Props) {
  const { control } = useFormContext()
  const { fields, append, remove } = useFieldArray({
    control,
    name: "extras",
  })

  const [extras, setExtras] = useState(initialExtras)

  return (
    <div className="space-y-4">
      <h3 className="text-lg font-semibold">Extras</h3>

      {fields.map((field, index) => (
        <div key={field.id} className="grid grid-cols-5 gap-4 items-end">
          {/* Extra Picker (combobox with create) */}
          <FormField
            control={control}
            name={`extras.${index}.extraId`}
            render={({ field: extraField }) => (
              <FormItem>
                <FormLabel>Extra</FormLabel>
                <FormControl>
                  <ComboboxCreateable
                    options={extras.map((e) => ({
                      label: e.name,
                      value: e.id,
                    }))}
                    selected={extraField.value}
                    onSelect={extraField.onChange}
                    onCreateNew={async (name) => {
                      const newExtra = await createCommissionExtra({ name })
                      setExtras((prev) => [...prev, newExtra])
                      extraField.onChange(newExtra.id)
                    }}
                  />
                </FormControl>
              </FormItem>
            )}
          />

          {/* Price */}
          <FormField
            control={control}
            name={`extras.${index}.price`}
            render={({ field }) => (
              <FormItem>
                <FormLabel>Price (€)</FormLabel>
                <FormControl>
                  <Input
                    type="number"
                    step="0.01"
                    {...field}
                    value={field.value ?? ""}
                    onChange={(e) =>
                      field.onChange(e.target.value === "" ? undefined : e.target.valueAsNumber)
                    }
                  />
                </FormControl>
              </FormItem>
            )}
          />

          {/* Price Percent */}
          <FormField
            control={control}
            name={`extras.${index}.pricePercent`}
            render={({ field }) => (
              <FormItem>
                <FormLabel>+ %</FormLabel>
                <FormControl>
                  <Input
                    type="number"
                    step="0.01"
                    {...field}
                    value={field.value ?? ""}
                    onChange={(e) =>
                      field.onChange(e.target.value === "" ? undefined : e.target.valueAsNumber)
                    }
                  />
                </FormControl>
              </FormItem>
            )}
          />

          {/* Range Slider */}
          <FormField
            control={control}
            name={`extras.${index}.priceRange`}
            render={({ field }) => {
              const [start, end] =
                typeof field.value === "string" && field.value.includes("–")
                  ? field.value.split("–").map(Number)
                  : [0, 0]

              return (
                <FormItem>
                  <FormLabel>Range</FormLabel>
                  <FormControl>
                    <DualRangeSlider
                      value={[start, end]}
                      onChange={([min, max]) =>
                        field.onChange(`${Math.min(min, max)}–${Math.max(min, max)}`)
                      }
                    />
                  </FormControl>
                </FormItem>
              )
            }}
          />

          {/* Remove Button */}
          <Button
            type="button"
            variant="destructive"
            onClick={() => remove(index)}
          >
            Remove
          </Button>
        </div>
      ))}

      <Button
        type="button"
        onClick={() =>
          append({
            extraId: "",
            price: undefined,
            pricePercent: undefined,
            priceRange: "0–0",
          })
        }
      >
        Add Extra
      </Button>
    </div>
  )
}
