"use client"

import { createCommissionOption } from "@/actions/items/commissions/types/newType"
import { Button } from "@/components/ui/button"
import { DualRangeSlider } from "@/components/ui/dual-range"
import {
  FormControl,
  FormField,
  FormItem,
  FormLabel,
} from "@/components/ui/form"
import { Input } from "@/components/ui/input"
import { CommissionOption } from "@/generated/prisma"
import { useState } from "react"
import { useFieldArray, useFormContext } from "react-hook-form"
import { ComboboxCreateable } from "./ComboboxCreateable"

type Props = {
  options: CommissionOption[]
}

export function CommissionOptionField({ options: initialOptions }: Props) {
  const { control } = useFormContext()
  const { fields, append, remove } = useFieldArray({
    control,
    name: "options",
  })

  const [options, setOptions] = useState(initialOptions)

  return (
    <div className="space-y-4">
      <h3 className="text-lg font-semibold">Options</h3>

      {fields.map((field, index) => (
        <div key={field.id} className="grid grid-cols-5 gap-4 items-end">
          {/* Option Picker (combobox with create) */}
          <FormField
            control={control}
            name={`options.${index}.optionId`}
            render={({ field: optionField }) => (
              <FormItem>
                <FormLabel>Option</FormLabel>
                <FormControl>
                  <ComboboxCreateable
                    options={options.map((o) => ({
                      label: o.name,
                      value: o.id,
                    }))}
                    selected={optionField.value}
                    onSelect={optionField.onChange}
                    onCreateNew={async (name) => {
                      const newOption = await createCommissionOption({ name })
                      setOptions((prev) => [...prev, newOption])
                      optionField.onChange(newOption.id)
                    }}
                  />
                </FormControl>
              </FormItem>
            )}
          />

          {/* Price */}
          <FormField
            control={control}
            name={`options.${index}.price`}
            render={({ field }) => (
              <FormItem>
                <FormLabel>Price (€)</FormLabel>
                <FormControl>
                  <Input
                    type="number"
                    step="0.01"
                    {...field}
                    value={field.value ?? ""}
                    onChange={(e) =>
                      field.onChange(e.target.value === "" ? undefined : e.target.valueAsNumber)
                    }
                  />
                </FormControl>
              </FormItem>
            )}
          />

          {/* Price Percent */}
          <FormField
            control={control}
            name={`options.${index}.pricePercent`}
            render={({ field }) => (
              <FormItem>
                <FormLabel>+ %</FormLabel>
                <FormControl>
                  <Input
                    type="number"
                    step="0.01"
                    {...field}
                    value={field.value ?? ""}
                    onChange={(e) =>
                      field.onChange(e.target.value === "" ? undefined : e.target.valueAsNumber)
                    }
                  />
                </FormControl>
              </FormItem>
            )}
          />

          {/* Price Range Slider */}
          <FormField
            control={control}
            name={`options.${index}.priceRange`}
            render={({ field }) => {
              const [start, end] =
                typeof field.value === "string" && field.value.includes("–")
                  ? field.value.split("–").map(Number)
                  : [0, 0]

              return (
                <FormItem>
                  <FormLabel>Range</FormLabel>
                  <FormControl>
                    <DualRangeSlider
                      value={[start, end]}
                      onChange={([min, max]) =>
                        field.onChange(`${Math.min(min, max)}–${Math.max(min, max)}`)
                      }
                    />
                  </FormControl>
                </FormItem>
              )
            }}
          />

          {/* Remove Button */}
          <Button
            type="button"
            variant="destructive"
            onClick={() => remove(index)}
          >
            Remove
          </Button>
        </div>
      ))}

      {/* Add Button */}
      <Button
        type="button"
        onClick={() =>
          append({
            optionId: "",
            price: undefined,
            pricePercent: undefined,
            priceRange: "0–0",
          })
        }
      >
        Add Option
      </Button>
    </div>
  )
}
